@@ -5,9 +5,11 @@ from teacher import TeacherCollection
 from section import SectionCollection
 from student import StudentCollection
 from term import TermCollection
+from attendance import AttendanceCollection
+from course_grade import CourseGradeCollection
 
 class Organization(ResourceInstance):
-  subresources = [CourseCollection, SchoolCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection]
+  subresources = [CourseCollection, SchoolCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection]
 
 
 class OrganizationCollection(ResourceCollection):
