@@ -4,9 +4,11 @@ from section import SectionCollection
 from student import StudentCollection
 from teacher import TeacherCollection
 from term import TermCollection
+from attendance import AttendanceCollection
+from course_grade import CourseGradeCollection
 
 class School(ResourceInstance):
-  subresources = [CourseCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection]
+  subresources = [CourseCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection]
 
 
 class SchoolCollection(ResourceCollection):
